from wsgiref.simple_server import make_server
from pyramid.config import Configurator
from pyramid.response import Response
from pycapo import CapoConfig
import smtplib
import chevron
import zope.sqlalchemy

from workspaces.schema import get_engine, get_session_factory
from workspaces.services import NotificationInfo

def get_tm_session(session_factory, transaction_manager):
    """
    Enable Zope's transaction manager on our session
    :param session_factory:
    :param transaction_manager:
    :return:
    """
    dbsession = session_factory()
    zope.sqlalchemy.register(dbsession, transaction_manager=transaction_manager)
    return dbsession


def send_email(request):
    json_packet = request.json_body
    print(json_packet)

    smtp_server = "smtp.aoc.nrao.edu"
    sender_email = "do-not-reply@nrao.edu"  # Enter your address
    receiver_email = json_packet["destination_email"]  # Enter receiver address
    template_name = request.matchdict["template_name"]

    try:
        template = request.notification_info.lookup_template(template_name)
    except Exception as e:
        return Response("An error occured looking up template: "+template_name+"\nerror: "+str(e))


    if template is None:
        return Response("No template '"+template_name+"' found.")


    args = {
        'template': template.content,
        'data': json_packet
    }
    try:
        contents = chevron.render(**args)
    except Exception as e:
        return Response("An error occured rendering template: "+str(template)+"\nerror: "+str(e))



    with smtplib.SMTP(smtp_server) as server:
        r = server.sendmail(sender_email, receiver_email, contents)

    if r == {}:
        return Response("Email sent.\n"+contents)
    else:
        return Response("Unable to send to address(es): "+r)


def list_templates(request):
    return Response('The notification service will go here.\n')

def main(global_config, **settings):
    with Configurator(settings=settings) as config:
        ##TODO: this should probably be changed to NotificationSettings, and new settings added to Capo.
        settings = CapoConfig().settings("edu.nrao.archive.workspaces.CapabilitySettings")

        print("settings: "+settings.__str__())

        session_factory = get_session_factory(get_engine())
        config.registry["dbsession_factory"] = session_factory

        # make notification_info available for use in Pyramid
        config.add_request_method(
            # r.tm is the transaction manager used by pyramid_tm
            lambda request: NotificationInfo(get_tm_session(session_factory, request.tm)),
            "notification_info",
            reify=True,
        )

        config.add_route('notify', '/notify/')
        config.add_route('send', '/notify/{template_name}/send')

        config.add_view(list_templates, route_name='notify')
        config.add_view(send_email, route_name='send')

        notification = config.make_wsgi_app()
        server = make_server('0.0.0.0', 3458, notification)
        server.serve_forever()

if __name__ == "__main__":
    main()